==> kubernetes-model-autoscaling-5.1.1-sources.jar: annotations/io/fabric8/kubernetes/api/model/autoscaling/v2beta2/ContainerResourceMetricStatusFluent.java <==
package io.fabric8.kubernetes.api.model.autoscaling.v2beta2;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

public interface ContainerResourceMetricStatusFluent<A extends io.fabric8.kubernetes.api.model.autoscaling.v2beta2.ContainerResourceMetricStatusFluent<A>> extends Fluent<A> {


    public String getContainer();
    public A withContainer(String container);
    public Boolean hasContainer();
    public A withNewContainer(String arg1);
    public A withNewContainer(StringBuilder arg1);
    public A withNewContainer(StringBuffer arg1);
    
/**
 * This method has been deprecated, please use method buildCurrent instead.
 * @return The buildable object.
 */
@Deprecated public MetricValueStatus getCurrent();
    public MetricValueStatus buildCurrent();
    public A withCurrent(MetricValueStatus current);
    public Boolean hasCurrent();
    public ContainerResourceMetricStatusFluent.CurrentNested<A> withNewCurrent();
    public ContainerResourceMetricStatusFluent.CurrentNested<A> withNewCurrentLike(MetricValueStatus item);
    public ContainerResourceMetricStatusFluent.CurrentNested<A> editCurrent();
    public ContainerResourceMetricStatusFluent.CurrentNested<A> editOrNewCurrent();
    public ContainerResourceMetricStatusFluent.CurrentNested<A> editOrNewCurrentLike(MetricValueStatus item);
    public String getName();
    public A withName(String name);
    public Boolean hasName();
    public A withNewName(String arg1);
    public A withNewName(StringBuilder arg1);
    public A withNewName(StringBuffer arg1);
    public interface CurrentNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,MetricValueStatusFluent<ContainerResourceMetricStatusFluent.CurrentNested<N>> {

            public N and();
            public N endCurrent();    }


}

==> kubernetes-model-autoscaling-5.3.0-sources.jar: annotations/io/fabric8/kubernetes/api/model/autoscaling/v2beta2/ContainerResourceMetricStatusFluent.java <==
package io.fabric8.kubernetes.api.model.autoscaling.v2beta2;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

public interface ContainerResourceMetricStatusFluent<A extends io.fabric8.kubernetes.api.model.autoscaling.v2beta2.ContainerResourceMetricStatusFluent<A>> extends Fluent<A> {


    public String getContainer();
    public A withContainer(String container);
    public Boolean hasContainer();
    public A withNewContainer(StringBuilder arg1);
    public A withNewContainer(int[] arg1,int arg2,int arg3);
    public A withNewContainer(char[] arg1);
    public A withNewContainer(StringBuffer arg1);
    public A withNewContainer(byte[] arg1,int arg2);
    public A withNewContainer(byte[] arg1);
    public A withNewContainer(char[] arg1,int arg2,int arg3);
    public A withNewContainer(byte[] arg1,int arg2,int arg3);
    public A withNewContainer(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewContainer(String arg1);
    
/**
 * This method has been deprecated, please use method buildCurrent instead.
 * @return The buildable object.
 */
@Deprecated public MetricValueStatus getCurrent();
    public MetricValueStatus buildCurrent();
    public A withCurrent(MetricValueStatus current);
    public Boolean hasCurrent();
    public ContainerResourceMetricStatusFluent.CurrentNested<A> withNewCurrent();
    public ContainerResourceMetricStatusFluent.CurrentNested<A> withNewCurrentLike(MetricValueStatus item);
    public ContainerResourceMetricStatusFluent.CurrentNested<A> editCurrent();
    public ContainerResourceMetricStatusFluent.CurrentNested<A> editOrNewCurrent();
    public ContainerResourceMetricStatusFluent.CurrentNested<A> editOrNewCurrentLike(MetricValueStatus item);
    public String getName();
    public A withName(String name);
    public Boolean hasName();
    public A withNewName(StringBuilder arg1);
    public A withNewName(int[] arg1,int arg2,int arg3);
    public A withNewName(char[] arg1);
    public A withNewName(StringBuffer arg1);
    public A withNewName(byte[] arg1,int arg2);
    public A withNewName(byte[] arg1);
    public A withNewName(char[] arg1,int arg2,int arg3);
    public A withNewName(byte[] arg1,int arg2,int arg3);
    public A withNewName(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewName(String arg1);
    public interface CurrentNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,MetricValueStatusFluent<ContainerResourceMetricStatusFluent.CurrentNested<N>> {

            public N and();
            public N endCurrent();    }


}
